@@ -29,6 +29,8 @@
  */
 static GbWidget gbwidget;
 
+static gchar *VisibleWindow = "GtkEventBox::visible_window";
+static gchar *AboveChild = "GtkEventBox::above_child";
 
 
 /******
@@ -57,13 +59,12 @@ gb_event_box_new (GbWidgetNewData * data)
 /*
  * Creates the components needed to edit the extra properties of this widget.
  */
-/*
-   static void
-   gb_event_box_create_properties(GtkWidget *widget, GbWidgetCreateArgData *data)
-   {
-
-   }
- */
+static void
+gb_event_box_create_properties(GtkWidget *widget, GbWidgetCreateArgData *data)
+{
+  property_add_bool (VisibleWindow, _("Visible Window:"), _("If the event box uses a visible window"));
+  property_add_bool (AboveChild, _("Above Child:"), _("If the event box window is above the child widget's window"));
+}
 
 
 
@@ -71,13 +72,14 @@ gb_event_box_new (GbWidgetNewData * data)
  * Gets the properties of the widget. This is used for both displaying the
  * properties in the property editor, and also for saving the properties.
  */
-/*
-   static void
-   gb_event_box_get_properties(GtkWidget *widget, GbWidgetGetArgData *data)
-   {
-
-   }
- */
+static void
+gb_event_box_get_properties(GtkWidget *widget, GbWidgetGetArgData *data)
+{
+  gb_widget_output_bool (data, VisibleWindow,
+			 gtk_event_box_get_visible_window (GTK_EVENT_BOX (widget)));
+  gb_widget_output_bool (data, AboveChild,
+			 gtk_event_box_get_above_child (GTK_EVENT_BOX (widget)));
+}
 
 
 
@@ -85,13 +87,19 @@ gb_event_box_new (GbWidgetNewData * data)
  * Sets the properties of the widget. This is used for both applying the
  * properties changed in the property editor, and also for loading.
  */
-/*
-   static void
-   gb_event_box_set_properties(GtkWidget *widget, GbWidgetSetArgData *data)
-   {
+static void
+gb_event_box_set_properties(GtkWidget *widget, GbWidgetSetArgData *data)
+{
+  gboolean visible_window, above_child;
 
-   }
- */
+  visible_window = gb_widget_input_bool (data, VisibleWindow);
+  if (data->apply)
+    gtk_event_box_set_visible_window (GTK_EVENT_BOX (widget), visible_window);
+
+  above_child = gb_widget_input_bool (data, AboveChild);
+  if (data->apply)
+    gtk_event_box_set_above_child (GTK_EVENT_BOX (widget), above_child);
+}
 
 
 
@@ -123,6 +131,18 @@ gb_event_box_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
       source_add (data, "  %s = gtk_event_box_new ();\n", data->wname);
     }
   gb_widget_write_standard_source (widget, data);
+
+  if (!gtk_event_box_get_visible_window (GTK_EVENT_BOX (widget)))
+    {
+      source_add (data, "  gtk_event_box_set_visible_window (GTK_EVENT_BOX (%s), FALSE);\n",
+		  data->wname);
+    }
+
+  if (gtk_event_box_get_above_child (GTK_EVENT_BOX (widget)))
+    {
+      source_add (data, "  gtk_event_box_set_above_child (GTK_EVENT_BOX (%s), TRUE);\n",
+		  data->wname);
+    }
 }
 
 
@@ -136,7 +156,8 @@ GbWidget *
 gb_event_box_init ()
 {
   /* Initialise the GTK type */
-  gtk_event_box_get_type ();
+  volatile GtkType type;
+  type = gtk_event_box_get_type ();
 
   /* Initialize the GbWidget structure */
   gb_widget_init_struct (&gbwidget);
@@ -147,10 +168,10 @@ gb_event_box_init ()
 
   /* Fill in any functions that this GbWidget has */
   gbwidget.gb_widget_new = gb_event_box_new;
+  gbwidget.gb_widget_create_properties = gb_event_box_create_properties;
+  gbwidget.gb_widget_get_properties    = gb_event_box_get_properties;
+  gbwidget.gb_widget_set_properties    = gb_event_box_set_properties;
 /*
-   gbwidget.gb_widget_create_properties = gb_event_box_create_properties;
-   gbwidget.gb_widget_get_properties    = gb_event_box_get_properties;
-   gbwidget.gb_widget_set_properties    = gb_event_box_set_properties;
    gbwidget.gb_widget_create_popup_menu = gb_event_box_create_popup_menu;
  */
   gbwidget.gb_widget_write_source = gb_event_box_write_source;
