@@ -32,21 +32,18 @@ static GbWidget gbwidget;
 static gchar *Mode = "GtkList::selection_mode";
 
 static const gchar *GbModeChoices[] =
-{"Single", "Browse", "Multiple",
- "Extended", NULL};
+{"Single", "Browse", "Multiple", NULL};
 static const gint GbModeValues[] =
 {
   GTK_SELECTION_SINGLE,
   GTK_SELECTION_BROWSE,
-  GTK_SELECTION_MULTIPLE,
-  GTK_SELECTION_EXTENDED
+  GTK_SELECTION_MULTIPLE
 };
 static const gchar *GbModeSymbols[] =
 {
   "GTK_SELECTION_SINGLE",
   "GTK_SELECTION_BROWSE",
-  "GTK_SELECTION_MULTIPLE",
-  "GTK_SELECTION_EXTENDED"
+  "GTK_SELECTION_MULTIPLE"
 };
 
 /******
@@ -184,7 +181,8 @@ GbWidget *
 gb_list_init ()
 {
   /* Initialise the GTK type */
-  gtk_list_get_type ();
+  volatile GtkType type;
+  type = gtk_list_get_type ();
 
   /* Initialize the GbWidget structure */
   gb_widget_init_struct (&gbwidget);
