@@ -32,6 +32,8 @@ GbWidget *gb_check_button_init ();
 GbWidget *gb_radio_button_init ();
 GbWidget *gb_option_menu_init ();
 GbWidget *gb_combo_init ();
+GbWidget *gb_combo_box_init ();
+GbWidget *gb_combo_box_entry_init ();
 GbWidget *gb_list_init ();
 GbWidget *gb_clist_init ();
 GbWidget *gb_spin_button_init ();
@@ -66,12 +68,16 @@ GbWidget *gb_alignment_init ();
 GbWidget *gb_event_box_init ();
 GbWidget *gb_scrolled_window_init ();
 GbWidget *gb_viewport_init ();
+GbWidget *gb_expander_init ();
 GbWidget *gb_curve_init ();
 GbWidget *gb_gamma_curve_init ();
 GbWidget *gb_color_selection_init ();
 GbWidget *gb_preview_init ();
 GbWidget *gb_window_init ();
 GbWidget *gb_dialog_init ();
+GbWidget *gb_file_chooser_button_init ();
+GbWidget *gb_file_chooser_widget_init ();
+GbWidget *gb_file_chooser_dialog_init ();
 GbWidget *gb_file_selection_init ();
 GbWidget *gb_color_selection_dialog_init ();
 GbWidget *gb_input_dialog_init ();
@@ -91,6 +97,17 @@ GbWidget *gb_custom_init();
 GbWidget *gb_layout_init();
 GbWidget *gb_text_view_init();
 GbWidget *gb_tree_view_init();
+GbWidget *gb_color_button_init();
+GbWidget *gb_font_button_init();
+GbWidget *gb_tool_item_init ();
+GbWidget *gb_tool_button_init ();
+GbWidget *gb_toggle_tool_button_init ();
+GbWidget *gb_radio_tool_button_init ();
+GbWidget *gb_separator_tool_item_init ();
+GbWidget *gb_about_dialog_init ();
+GbWidget *gb_icon_view_init ();
+GbWidget *gb_menu_tool_button_init ();
+GbWidget *gb_cell_view_init ();
 
 
 static GladeWidgetInitData gtk_standard[] =
@@ -100,9 +117,14 @@ static GladeWidgetInitData gtk_standard[] =
   { "GtkToolbar", gb_toolbar_init },
   { "GtkHandleBox", gb_handle_box_init },
 
+  { "GtkToolButton", gb_tool_button_init },
+  { "GtkToggleToolButton", gb_toggle_tool_button_init },
+  { "GtkRadioToolButton", gb_radio_tool_button_init },
+  { "GtkSeparatorToolItem", gb_separator_tool_item_init },
+
   { "GtkLabel", gb_label_init },
   { "GtkEntry", gb_entry_init },
-  { "GtkCombo", gb_combo_init },
+  { "GtkComboBoxEntry", gb_combo_box_entry_init },
   { "GtkTextView", gb_text_view_init },
 
   { "GtkButton", gb_button_init },
@@ -110,10 +132,10 @@ static GladeWidgetInitData gtk_standard[] =
   { "GtkCheckButton", gb_check_button_init },
   { "GtkRadioButton", gb_radio_button_init },
 
-  { "GtkOptionMenu", gb_option_menu_init },
+  { "GtkComboBox", gb_combo_box_init },
   { "GtkSpinButton", gb_spin_button_init },
-  { "GtkStatusbar", gb_statusbar_init },
   { "GtkTreeView", gb_tree_view_init },
+  { "GtkIconView", gb_icon_view_init },
 
   { "GtkHSeparator", gb_hseparator_init },
   { "GtkVSeparator", gb_vseparator_init },
@@ -121,7 +143,7 @@ static GladeWidgetInitData gtk_standard[] =
   { "GtkDrawingArea", gb_drawing_area_init },
 
   { "GtkDialog", gb_dialog_init },
-  { "GtkFileSelection", gb_file_selection_init },
+  { "GtkFileChooserDialog", gb_file_chooser_dialog_init },
   { "GtkColorSelectionDialog", gb_color_selection_dialog_init },
   { "GtkFontSelectionDialog", gb_font_selection_dialog_init },
 
@@ -138,7 +160,8 @@ static GladeWidgetInitData gtk_standard[] =
   { "GtkNotebook", gb_notebook_init },
   { "GtkFrame", gb_frame_init },
   { "GtkScrolledWindow", gb_scrolled_window_init },
-  { "GtkViewport", gb_viewport_init },
+  { "GtkStatusbar", gb_statusbar_init },
+
 
   { NULL, NULL }
 };
@@ -146,6 +169,11 @@ static GladeWidgetInitData gtk_standard[] =
 
 static GladeWidgetInitData gtk_advanced[] =
 {
+  { "GtkAboutDialog", gb_about_dialog_init },
+  { "GtkInputDialog", gb_input_dialog_init },
+  { "GtkMenuToolButton", gb_menu_tool_button_init },
+  { "GtkToolItem", gb_tool_item_init },
+
   { "GtkHScale", gb_hscale_init },
   { "GtkVScale", gb_vscale_init },
   { "GtkHRuler", gb_hruler_init },
@@ -158,17 +186,27 @@ static GladeWidgetInitData gtk_advanced[] =
 
   { "GtkLayout", gb_layout_init },
   { "GtkAspectFrame", gb_aspect_frame_init },
-  { "GtkMenu", gb_menu_init },
   { "GtkArrow", gb_arrow_init },
+  { "GtkExpander", gb_expander_init },
+
 
   { "GtkCurve", gb_curve_init },
   { "GtkGammaCurve", gb_gamma_curve_init },
   { "GtkHScrollbar", gb_hscrollbar_init },
   { "GtkVScrollbar", gb_vscrollbar_init },
 
+  { "GtkFileChooserWidget", gb_file_chooser_widget_init },
   { "GtkColorSelection", gb_color_selection_init },
   { "GtkFontSelection", gb_font_selection_init },
-  { "GtkInputDialog", gb_input_dialog_init },
+  { "GtkCellView", gb_cell_view_init },
+
+  { "GtkFileChooserButton", gb_file_chooser_button_init },
+  { "GtkColorButton", gb_color_button_init },
+  { "GtkFontButton", gb_font_button_init },
+  { "GtkMenu", gb_menu_init },
+
+  { "GtkViewport", gb_viewport_init },
+
   { "Custom", gb_custom_init }, /* Our special custom widget. */
 
   { NULL, NULL }
@@ -176,9 +214,13 @@ static GladeWidgetInitData gtk_advanced[] =
 
 static GladeWidgetInitData gtk_deprecated[] =
 {
-  { "GtkList", gb_list_init },
   { "GtkCList", gb_clist_init },
   { "GtkCTree", gb_ctree_init },
+  { "GtkList", gb_list_init },
+  { "GtkCombo", gb_combo_init },
+
+  { "GtkFileSelection", gb_file_selection_init },
+  { "GtkOptionMenu", gb_option_menu_init },
   { "GtkPreview", gb_preview_init },
 
   { NULL, NULL }
