@@ -15,8 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
-#ifndef __KEYS_H__
-#define __KEYS_H__
+#ifndef GLADE_KEYS_H
+#define GLADE_KEYS_H
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 
 typedef struct _GbKey  GbKey;
 struct _GbKey
@@ -29,7 +34,11 @@ struct _GbKey
    These are used for the GladeKeysDialog.
    Note that in GTK 1.0 accelerator keys are a guchar which means that only
    keys with values 0-255 can be used. In GTK 1.1 a guint is used. */
-extern GbKey GbKeys[];
+extern const GbKey GbKeys[];
 
 
-#endif	/* __KEYS_H__ */
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif	/* GLADE_KEYS_H */
